drop procedure if exists lt1_shop_dash_order_delayed;

DELIMITER //
CREATE PROCEDURE lt1_shop_dash_order_delayed( _listToken varchar(21), _sdate varchar(8), _edate varchar(8),
                                              _s1 varchar(32), _e1 varchar(32), _s2 varchar(32), _e2 varchar(32),
                                              _s3 varchar(32), _e3 varchar(32), _s4 varchar(32), _e4 varchar(32),
                                              _where varchar(386), _having varchar(386), _orderby varchar(64),
                                              _branch int, _storage int)
BEGIN

-- 로컬 변수 선언
    DECLARE order_wait_pay_days INT;
    DECLARE ship_wait_days INT;
    DECLARE cancel_wait_days INT;
    DECLARE return_wait_days INT;
    DECLARE exchange_wait_days INT;

    -- dbr_setup 테이블에서 id=1인 값을 변수에 저장
    SELECT
        JSON_UNQUOTE(JSON_EXTRACT(setup_json, '$.OrderWaitPayDays')),
        JSON_UNQUOTE(JSON_EXTRACT(setup_json, '$.ShipWaitDays')),
        JSON_UNQUOTE(JSON_EXTRACT(setup_json, '$.CancelWaitDays')),
        JSON_UNQUOTE(JSON_EXTRACT(setup_json, '$.ReturnWaitDays')),
        JSON_UNQUOTE(JSON_EXTRACT(setup_json, '$.ExchangeWaitDays'))
    INTO
        order_wait_pay_days,
        ship_wait_days,
        cancel_wait_days,
        return_wait_days,
        exchange_wait_days
    FROM dbr_setup
    WHERE setup_code = 'user-scheduler';

    -- 최종 쿼리 실행
insert into dbt_list_type1
( created_on, list_token, c1, c2, c3, c4, c5, c6, c7 )

SELECT
	unix_timestamp(),
    _listToken,
    c1,
    c2,
    c3,
    c4,
    ROUND(c2 * 100.0 / NULLIF(c1, 0), 2) AS c5,
    ROUND(c3 * 100.0 / NULLIF(c1, 0), 2) AS c6,
    ROUND(c4 * 100.0 / NULLIF(c1, 0), 2) AS c7
FROM (
    SELECT
        COUNT(
            CASE
                WHEN (mx.status = '2' AND STR_TO_DATE(mx.sorder_date, '%Y%m%d') < CURDATE() - INTERVAL ship_wait_days DAY)
                  OR (mx.status = 'C' AND mx.situation = 'RM' AND STR_TO_DATE(mx.sorder_date, '%Y%m%d') < CURDATE() - INTERVAL return_wait_days DAY)
                  OR (mx.status = 'C' AND mx.situation = 'EM' AND STR_TO_DATE(mx.sorder_date, '%Y%m%d') < CURDATE() - INTERVAL exchange_wait_days DAY)
                THEN mx.id
            END
        ) AS c1,
        COUNT(CASE WHEN mx.status = '2' AND STR_TO_DATE(mx.sorder_date, '%Y%m%d') < CURDATE() - INTERVAL ship_wait_days DAY THEN mx.id END) AS c2,
        COUNT(CASE WHEN mx.status = 'C' AND mx.situation = 'RM' AND STR_TO_DATE(mx.sorder_date, '%Y%m%d') < CURDATE() - INTERVAL return_wait_days DAY THEN mx.id END) AS c3,
        COUNT(CASE WHEN mx.status = 'C' AND mx.situation = 'EM' AND STR_TO_DATE(mx.sorder_date, '%Y%m%d') < CURDATE() - INTERVAL exchange_wait_days DAY THEN mx.id END) AS c4
    FROM
        dbr_sorder AS mx
) subquery;

END //

DELIMITER ;

CALL lt1_shop_dash_order_delayed('', '', '', '', '', '', '', '',
'', '', '', '', '', '', 1, 1);
