drop procedure if exists zds_door_sales_cancel_month;

DELIMITER //
CREATE PROCEDURE zds_door_sales_cancel_month( _listToken varchar(21), _sdate varchar(8), _edate varchar(8),
                                              _s1 varchar(32), _e1 varchar(32), _s2 varchar(32), _e2 varchar(32),
                                              _s3 varchar(32), _e3 varchar(32), _s4 varchar(32), _e4 varchar(32),
                                              _where varchar(386), _having varchar(386), _orderby varchar(64),
                                              _branch int, _storage int)
BEGIN
	  DECLARE start_date varchar(8);
	  DECLARE end_date varchar(8);
    DECLARE previous_month_start_date DATE;
    DECLARE previous_month_end_date DATE;

	  set start_date = _sdate;
		set end_date = _edate;

    -- 한 달 전의 시작일과 종료일 계산
    SET previous_month_start_date = DATE_SUB(DATE_ADD(start_date, INTERVAL -1 MONTH), INTERVAL DAY(start_date)-1 DAY);
    SET previous_month_end_date = LAST_DAY(DATE_SUB(start_date, INTERVAL 1 MONTH));

    -- 최종 쿼리 실행
insert into dbt_list_type1
( created_on, list_token, c1, c2, c3,
  c4, c5, c6 )

SELECT
    unix_timestamp(),
    _listToken,
    company_name AS c1,
    company_no AS c2,
    item_name AS c3,
    COALESCE(sum_sorder_qty_6, 0) AS c4,
    COALESCE(sum_sorder_claim_qty_7, 0) AS c5,
    COALESCE(CONCAT(ROUND((COALESCE(sum_sorder_claim_qty_7, 0) / NULLIF(COALESCE(sum_sorder_qty_6, 0), 0) * 100), 1), '%'), '0.0%') AS c6
FROM (
    SELECT
    mc.company_name as company_name,
    md.item_name as item_name,
    june_data.sum_sorder_qty as sum_sorder_qty_6,
    july_data.sum_sorder_claim_qty as sum_sorder_claim_qty_7,
    mc.company_no as company_no
    FROM dbr_company as mc
    INNER JOIN dbr_cgroup as me ON mc.cgroup_id = me.id
    INNER JOIN dbr_sorder as mx_june ON mc.id = mx_june.seller_id
    INNER JOIN dbr_sorder_bd as mb_june ON mx_june.id = mb_june.sorder_id
    INNER JOIN dbr_item as md ON mb_june.item_id = md.id
    LEFT JOIN (
    SELECT
    seller_id,
    item_id,
    SUM(sorder_qty) as sum_sorder_qty
    FROM dbr_sorder as mx
    INNER JOIN dbr_sorder_bd as mb ON mx.id = mb.sorder_id
    WHERE true  and reward_date between '20240801' and '20240831' AND sorder_date >= previous_month_start_date and sorder_date <= previous_month_end_date
    GROUP BY seller_id, item_id
    ) as june_data ON mc.id = june_data.seller_id AND md.id = june_data.item_id
    LEFT JOIN (
    SELECT
    seller_id,
    item_id,
    SUM(CASE WHEN mx.status = 'C' THEN sorder_qty ELSE 0 END) AS sum_sorder_claim_qty
    FROM dbr_sorder as mx
    INNER JOIN dbr_sorder_bd as mb ON mx.id = mb.sorder_id
    WHERE  true  and reward_date between '20240801' and '20240831' AND  sorder_date >= start_date and sorder_date <= end_date
    GROUP BY seller_id, item_id
    ) as july_data ON mc.id = july_data.seller_id AND md.id = july_data.item_id
    WHERE me.cgroup_code = 'A-0001'
    GROUP BY mc.id, md.id
    ) AS sorted_data
WHERE COALESCE(sum_sorder_qty_6, 0) > 0 OR COALESCE(sum_sorder_claim_qty_7, 0) > 0
ORDER BY c1, c6 DESC;
END //

DELIMITER ;